"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSql import *


class QSqlDatabase(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsqldatabase.html

    **Detailed Description**

    The QSqlDatabase class provides an interface for accessing a database
    through a connection. An instance of QSqlDatabase represents the connection.
    The connection provides access to the database via one of the **supported
    database drivers** , which are derived from **QSqlDriver** . Alternatively,
    you can subclass your own database driver from **QSqlDriver** . See **How to
    Write Your Own Database Driver**  for more information.

    Create a connection (i.e., an instance of QSqlDatabase) by calling one of
    the static **addDatabase** () functions, where you specify **the driver or
    type of driver**  to use (depending on the type of database) and a
    connection name. A connection is known by its own name, **not** by the name
    of the database it connects to. You can have multiple connections to one
    database. QSqlDatabase also supports the concept of a **default**
    connection, which is the unnamed connection. To create the default
    connection, don't pass the connection name argument when you call
    **addDatabase** (). Subsequently, the default connection will be assumed if
    you call any static member function without specifying the connection name.
    The following snippet shows how to create and open a default connection to a
    PostgreSQL database:

    **QSqlDatabase**  db = **QSqlDatabase** ::addDatabase("QPSQL");
    db.setHostName("acidalia");
            db.setDatabaseName("customdb");
    db.setUserName("mojito");
            db.setPassword("J0a1m8");
            bool ok
    = db.open();

    Once the QSqlDatabase object has been created, set the connection parameters
    with **setDatabaseName** (), **setUserName** (), **setPassword** (),
    **setHostName** (), **setPort** (), and **setConnectOptions** (). Then call
    **open** () to activate the physical connection to the database. The
    connection is not usable until you open it.

    The connection defined above will be the **default** connection, because we
    didn't give a connection name to **addDatabase** (). Subsequently, you can
    get the default connection by calling **database** () without the connection
    name argument:

    **QSqlDatabase**  db = **QSqlDatabase** ::database();

    QSqlDatabase is a value class. Changes made to a database connection via one
    instance of QSqlDatabase will affect other instances of QSqlDatabase that
    represent the same connection. Use **cloneDatabase** () to create an
    independent database connection based on an existing one.

    **Warning:** It is highly recommended that you do not keep a copy of the
    QSqlDatabase around as a member of a class, as this will prevent the
    instance from being correctly cleaned up on shutdown. If you need to access
    an existing QSqlDatabase, it should be accessed with **database** (). If you
    chose to have a QSqlDatabase member variable, this needs to be deleted
    before the **QCoreApplication**  instance is deleted, otherwise it may lead
    to undefined behavior.

    If you create multiple database connections, specify a unique connection
    name for each one, when you call **addDatabase** (). Use **database** ()
    with a connection name to get that connection. Use **removeDatabase** ()
    with a connection name to remove a connection. QSqlDatabase outputs a
    warning if you try to remove a connection referenced by other QSqlDatabase
    objects. Use **contains** () to see if a given connection name is in the
    list of connections.

    Some utility methods:
    **tables** ()returns the list of tables
    **primaryIndex** ()returns a table's primary index
    **record** ()returns
    meta-information about a table's fields
    **transaction** ()starts a
    transaction
    **commit** ()saves and completes a transaction
    **rollback**
    ()cancels a transaction
    hasFeature()checks if a driver supports
    transactions
    **lastError** ()returns information about the last error
    **drivers** ()returns the names of the available SQL drivers
    **isDriverAvailable** ()checks if a particular driver is available
    **registerSqlDriver** ()registers a custom-made driver

    **Note:****QSqlDatabase::exec** () is deprecated. Use **QSqlQuery::exec** ()
    instead.

    **Note:** When using transactions, you must start the transaction before you
    create your query.

    **See also** **QSqlDriver** , **QSqlQuery** , **Qt SQL** , and **Threads and
    the SQL Module** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#QSqlDatabase

        **QSqlDatabase::QSqlDatabase()**

        Creates an empty, invalid QSqlDatabase object. Use **addDatabase** (),
        **removeDatabase** (), and **database** () to get valid QSqlDatabase
        objects.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlDatabase") -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#QSqlDatabase-1

        **QSqlDatabase::QSqlDatabase(const QSqlDatabase & other )**

        Creates a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, type: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#QSqlDatabase-2

        **[protected] QSqlDatabase::QSqlDatabase(const QString & type )**

        This is an overloaded function.

        Creates a QSqlDatabase connection that uses the driver referred to by
        **type**. If the **type** is not recognized, the database connection
        will have no functionality.

        The currently available driver types are:

        Driver TypeDescription
        QDB2IBM DB2
        QIBASEBorland InterBase Driver
        QMYSQLMySQL Driver
        QOCIOracle Call Interface Driver
        QODBCODBC Driver
        (includes Microsoft SQL Server)
        QPSQLPostgreSQL Driver
        QSQLITESQLite
        version 3 or above

        Additional third party drivers, including your own custom drivers, can
        be loaded dynamically.

        **See also** **SQL Database Drivers** , **registerSqlDriver** (), and
        **drivers** ().
        """
        ...

    @typing.overload
    def __init__(self, driver: "QSqlDriver") -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#QSqlDatabase-3

        **[protected] QSqlDatabase::QSqlDatabase(QSqlDriver * driver )**

        This is an overloaded function.

        Creates a database connection using the given **driver**.
        """
        ...

    def numericalPrecisionPolicy(self) -> "QSql.NumericalPrecisionPolicy":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#numericalPrecisionPolicy

        **QSql::NumericalPrecisionPolicy
        QSqlDatabase::numericalPrecisionPolicy() const**

        Returns the current default precision policy for the database
        connection.

        **See also** **QSql::NumericalPrecisionPolicy** ,
        **setNumericalPrecisionPolicy** (),
        **QSqlQuery::numericalPrecisionPolicy** (), and
        **QSqlQuery::setNumericalPrecisionPolicy** ().
        """
        ...

    def setNumericalPrecisionPolicy(
        self, precisionPolicy: "QSql.NumericalPrecisionPolicy"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setNumericalPrecisionPolicy

        **void
        QSqlDatabase::setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy
        precisionPolicy )**

        Sets the default numerical precision policy used by queries created on
        this database connection to **precisionPolicy**.

        Note: Drivers that don't support fetching numerical values with low
        precision will ignore the precision policy. You can use
        **QSqlDriver::hasFeature** () to find out whether a driver supports this
        feature.

        Note: Setting the default precision policy to **precisionPolicy**
        doesn't affect any currently active queries.

        **See also** **QSql::NumericalPrecisionPolicy** ,
        **numericalPrecisionPolicy** (),
        **QSqlQuery::setNumericalPrecisionPolicy** (), and
        **QSqlQuery::numericalPrecisionPolicy** ().
        """
        ...

    @staticmethod
    def isDriverAvailable(name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#isDriverAvailable

        **[static] bool QSqlDatabase::isDriverAvailable(const QString & name )**

        Returns `true` if a driver called **name** is available; otherwise
        returns `false`.

        **See also** **drivers** ().
        """
        ...

    @staticmethod
    def registerSqlDriver(name: str, creator: QSqlDriverCreatorBase) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#registerSqlDriver

        **[static] void QSqlDatabase::registerSqlDriver(const QString & name ,
        QSqlDriverCreatorBase * creator )**

        This function registers a new SQL driver called **name** , within the
        SQL framework. This is useful if you have a custom SQL driver and don't
        want to compile it as a plugin.

        Example:

        **QSqlDatabase** ::registerSqlDriver("MYDRIVER", new
        **QSqlDriverCreator** <**QSqlDriver** >);
            QVERIFY(**QSqlDatabase**
        ::drivers().contains("MYDRIVER"));
            **QSqlDatabase**  db =
        **QSqlDatabase** ::addDatabase("MYDRIVER");
            QVERIFY(db.isValid());

        **QSqlDatabase**  takes ownership of the **creator** pointer, so you
        mustn't delete it yourself.

        **See also** **drivers** ().
        """
        ...

    @staticmethod
    def connectionNames() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#connectionNames

        **[static] QStringList QSqlDatabase::connectionNames()**

        Returns a list containing the names of all connections.

        **Note:** This function is **thread-safe** .

        **See also** **contains** (), **database** (), and **Threads and the SQL
        Module** .
        """
        ...

    @staticmethod
    def drivers() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#drivers

        **[static] QStringList QSqlDatabase::drivers()**

        Returns a list of all the available database drivers.

        **See also** **registerSqlDriver** ().
        """
        ...

    @staticmethod
    def contains(connectionName: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#contains

        **[static] bool QSqlDatabase::contains(const QString & connectionName =
        QLatin1String(defaultConnection))**

        Returns `true` if the list of database connections contains
        **connectionName** ; otherwise returns `false`.

        **Note:** This function is **thread-safe** .

        **See also** **connectionNames** (), **database** (), and **Threads and
        the SQL Module** .
        """
        ...

    @staticmethod
    def removeDatabase(connectionName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#removeDatabase

        **[static] void QSqlDatabase::removeDatabase(const QString &
        connectionName )**

        Removes the database connection **connectionName** from the list of
        database connections.

        **Warning:** There should be no open queries on the database connection
        when this function is called, otherwise a resource leak will occur.

        Example:

        // WRONG
            **QSqlDatabase**  db = **QSqlDatabase**
        ::database("sales");
            **QSqlQuery**  query("SELECT NAME, DOB FROM
        EMPLOYEES", db);
            **QSqlDatabase** ::removeDatabase("sales"); // will
        output a warning
            // "db" is now a dangling invalid database
        connection,
            // "query" contains an invalid result set

        The correct way to do it:

        {
                **QSqlDatabase**  db = **QSqlDatabase** ::database("sales");
        **QSqlQuery**  query("SELECT NAME, DOB FROM EMPLOYEES", db);
            }
        // Both "db" and "query" are destroyed because they are out of scope
        **QSqlDatabase** ::removeDatabase("sales"); // correct

        To remove the default connection, which may have been created with a
        call to **addDatabase** () not specifying a connection name, you can
        retrieve the default connection name by calling **connectionName** () on
        the database returned by **database** (). Note that if a default
        database hasn't been created an invalid database will be returned.

        **Note:** This function is **thread-safe** .

        **See also** **database** (), **connectionName** (), and **Threads and
        the SQL Module** .
        """
        ...

    @staticmethod
    def database(connectionName: str = ..., open: bool = ...) -> "QSqlDatabase":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#database

        **[static] QSqlDatabase QSqlDatabase::database(const QString &
        connectionName = QLatin1String(defaultConnection), bool open = true)**

        Returns the database connection called **connectionName**. The database
        connection must have been previously added with **addDatabase** (). If
        **open** is true (the default) and the database connection is not
        already open it is opened now. If no **connectionName** is specified the
        default connection is used. If **connectionName** does not exist in the
        list of databases, an invalid connection is returned.

        **Note:** This function is **thread-safe** .

        **See also** **isOpen** () and **Threads and the SQL Module** .
        """
        ...

    @typing.overload
    @staticmethod
    def cloneDatabase(other: "QSqlDatabase", connectionName: str) -> "QSqlDatabase":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#cloneDatabase

        **[static] QSqlDatabase QSqlDatabase::cloneDatabase(const QSqlDatabase &
        other , const QString & connectionName )**

        Clones the database connection **other** and stores it as
        **connectionName**. All the settings from the original database, e.g.
        **databaseName** (), **hostName** (), etc., are copied across. Does
        nothing if **other** is an invalid database. Returns the newly created
        database connection.

        **Note:** The new connection has not been opened. Before using the new
        connection, you must call **open** ().
        """
        ...

    @typing.overload
    @staticmethod
    def cloneDatabase(other: str, connectionName: str) -> "QSqlDatabase":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#cloneDatabase-1

        **[static, since 5.13] QSqlDatabase QSqlDatabase::cloneDatabase(const
        QString & other , const QString & connectionName )**

        This is an overloaded function.

        Clones the database connection **other** and stores it as
        **connectionName**. All the settings from the original database, e.g.
        **databaseName** (), **hostName** (), etc., are copied across. Does
        nothing if **other** is an invalid database. Returns the newly created
        database connection.

        **Note:** The new connection has not been opened. Before using the new
        connection, you must call **open** ().

        This overload is useful when cloning the database in another thread to
        the one that is used by the database represented by **other**.

        This function was introduced in Qt 5.13.
        """
        ...

    @typing.overload
    @staticmethod
    def addDatabase(type: str, connectionName: str = ...) -> "QSqlDatabase":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#addDatabase

        **[static] QSqlDatabase QSqlDatabase::addDatabase(const QString & type ,
        const QString & connectionName = QLatin1String(defaultConnection))**

        Adds a database to the list of database connections using the driver
        **type** and the connection name **connectionName**. If there already
        exists a database connection called **connectionName** , that connection
        is removed.

        The database connection is referred to by **connectionName**. The newly
        added database connection is returned.

        If **type** is not available or could not be loaded, **isValid** ()
        returns `false`.

        If **connectionName** is not specified, the new connection becomes the
        default connection for the application, and subsequent calls to
        **database** () without the connection name argument will return the
        default connection. If a **connectionName** is provided here, use
        database( **connectionName** ) to retrieve the connection.

        **Warning:** If you add a connection with the same name as an existing
        connection, the new connection replaces the old one. If you call this
        function more than once without specifying **connectionName** , the
        default connection will be the one replaced.

        Before using the connection, it must be initialized. e.g., call some or
        all of **setDatabaseName** (), **setUserName** (), **setPassword** (),
        **setHostName** (), **setPort** (), and **setConnectOptions** (), and,
        finally, **open** ().

        **Note:** This function is **thread-safe** .

        **See also** **database** (), **removeDatabase** (), and **Threads and
        the SQL Module** .
        """
        ...

    @typing.overload
    @staticmethod
    def addDatabase(driver: "QSqlDriver", connectionName: str = ...) -> "QSqlDatabase":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#addDatabase-1

        **[static] QSqlDatabase QSqlDatabase::addDatabase(QSqlDriver * driver ,
        const QString & connectionName = QLatin1String(defaultConnection))**

        This overload is useful when you want to create a database connection
        with a **driver**  you instantiated yourself. It might be your own
        database driver, or you might just need to instantiate one of the Qt
        drivers yourself. If you do this, it is recommended that you include the
        driver code in your application. For example, you can create a
        PostgreSQL connection with your own QPSQL driver like this:

        PGconn *con = PQconnectdb("host=server user=bart password=simpson
        dbname=springfield");
            QPSQLDriver *drv = new QPSQLDriver(con);
        **QSqlDatabase**  db = **QSqlDatabase** ::addDatabase(drv); // becomes
        the new default connection
            **QSqlQuery**  query;
        query.exec("SELECT NAME, ID FROM STAFF");

        The above code sets up a PostgreSQL connection and instantiates a
        QPSQLDriver object. Next, addDatabase() is called to add the connection
        to the known connections so that it can be used by the Qt SQL classes.
        When a driver is instantiated with a connection handle (or set of
        handles), Qt assumes that you have already opened the database
        connection.

        **Note:** We assume that `qtdir` is the directory where Qt is installed.
        This will pull in the code that is needed to use the PostgreSQL client
        library and to instantiate a QPSQLDriver object, assuming that you have
        the PostgreSQL headers somewhere in your include search path.

        Remember that you must link your application against the database client
        library. Make sure the client library is in your linker's search path,
        and add lines like these to your `.pro` file:

        unix:LIBS += -lpq
            win32:LIBS += libpqdll.lib

        The method described works for all the supplied drivers. The only
        difference will be in the driver constructor arguments. Here is a table
        of the drivers included with Qt, their source code files, and their
        constructor arguments:

        DriverClass nameConstructor argumentsFile to include
        QPSQLQPSQLDriverPGconn *connection`qsql_psql.cpp`
        QMYSQLQMYSQLDriverMYSQL *connection`qsql_mysql.cpp`
        QOCIQOCIDriverOCIEnv *environment, OCISvcCtx
        *serviceContext`qsql_oci.cpp`
        QODBCQODBCDriverSQLHANDLE environment,
        SQLHANDLE connection`qsql_odbc.cpp`
        QDB2QDB2SQLHANDLE environment,
        SQLHANDLE connection`qsql_db2.cpp`
        QSQLITEQSQLiteDriversqlite
        *connection`qsql_sqlite.cpp`
        QIBASEQIBaseDriverisc_db_handle
        connection`qsql_ibase.cpp`

        **Warning:** Adding a database connection with the same connection name
        as an existing connection, causes the existing connection to be replaced
        by the new one.

        **Warning:** The SQL framework takes ownership of the **driver**. It
        must not be deleted. To remove the connection, use **removeDatabase**
        ().

        **See also** **drivers** ().
        """
        ...

    def driver(self) -> "QSqlDriver":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#driver

        **QSqlDriver *QSqlDatabase::driver() const**

        Returns the database driver used to access the database connection.

        **See also** **addDatabase** () and **drivers** ().
        """
        ...

    def connectionName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#connectionName

        **QString QSqlDatabase::connectionName() const**

        Returns the connection name, which may be empty.

        **Note:** The connection name is not the **database name** .

        **See also** **addDatabase** ().
        """
        ...

    def connectOptions(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#connectOptions

        **QString QSqlDatabase::connectOptions() const**

        Returns the connection options string used for this connection. The
        string may be empty.

        **See also** **setConnectOptions** ().
        """
        ...

    def port(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#port

        **int QSqlDatabase::port() const**

        Returns the connection's port number. The value is undefined if the port
        number has not been set.

        **See also** **setPort** ().
        """
        ...

    def driverName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#driverName

        **QString QSqlDatabase::driverName() const**

        Returns the connection's driver name.

        **See also** **addDatabase** () and **driver** ().
        """
        ...

    def hostName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#hostName

        **QString QSqlDatabase::hostName() const**

        Returns the connection's host name; it may be empty.

        **See also** **setHostName** ().
        """
        ...

    def password(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#password

        **QString QSqlDatabase::password() const**

        Returns the connection's password. An empty string will be returned if
        the password was not set with **setPassword** (), and if the password
        was given in the **open** () call, or if no password was used.

        **See also** **setPassword** ().
        """
        ...

    def userName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#userName

        **QString QSqlDatabase::userName() const**

        Returns the connection's user name; it may be empty.

        **See also** **setUserName** ().
        """
        ...

    def databaseName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#databaseName

        **QString QSqlDatabase::databaseName() const**

        Returns the connection's database name, which may be empty.

        **Note:** The database name is not the connection name.

        **See also** **setDatabaseName** ().
        """
        ...

    def setConnectOptions(self, options: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setConnectOptions

        **void QSqlDatabase::setConnectOptions(const QString & options =
        QString())**

        Sets database-specific **options**. This must be done before the
        connection is opened, otherwise it has no effect. Another possibility is
        to close the connection, call QSqlDatabase::setConnectOptions(), and
        **open** () the connection again.

        The format of the **options** string is a semicolon separated list of
        option names or option=value pairs. The options depend on the database
        client used:

        ODBCMySQLPostgreSQL

          * SQL_ATTR_ACCESS_MODE
          *
        SQL_ATTR_LOGIN_TIMEOUT
          * SQL_ATTR_CONNECTION_TIMEOUT
          *
        SQL_ATTR_CURRENT_CATALOG
          * SQL_ATTR_METADATA_ID
          *
        SQL_ATTR_PACKET_SIZE
          * SQL_ATTR_TRACEFILE
          * SQL_ATTR_TRACE
          *
        SQL_ATTR_CONNECTION_POOLING
          * SQL_ATTR_ODBC_VERSION

          *
        CLIENT_COMPRESS
          * CLIENT_FOUND_ROWS
          * CLIENT_IGNORE_SPACE
          *
        CLIENT_ODBC
          * CLIENT_NO_SCHEMA
          * CLIENT_INTERACTIVE
          * UNIX_SOCKET
        * MYSQL_OPT_RECONNECT
          * MYSQL_OPT_CONNECT_TIMEOUT
          *
        MYSQL_OPT_READ_TIMEOUT
          * MYSQL_OPT_WRITE_TIMEOUT
          * SSL_KEY
          *
        SSL_CERT
          * SSL_CA
          * SSL_CAPATH
          * SSL_CIPHER

          * connect_timeout
        * options
          * tty
          * requiressl
          * service


        DB2OCI

          *
        SQL_ATTR_ACCESS_MODE
          * SQL_ATTR_LOGIN_TIMEOUT

          *
        OCI_ATTR_PREFETCH_ROWS
          * OCI_ATTR_PREFETCH_MEMORY


        SQLiteInterbase
        * QSQLITE_BUSY_TIMEOUT
          * QSQLITE_OPEN_READONLY
          * QSQLITE_OPEN_URI
        * QSQLITE_ENABLE_SHARED_CACHE
          * QSQLITE_ENABLE_REGEXP
          *
        QSQLITE_NO_USE_EXTENDED_RESULT_CODES

          * ISC_DPB_LC_CTYPE
          *
        ISC_DPB_SQL_ROLE_NAME

        Examples:

        db.setConnectOptions("SSL_KEY=client-key.pem;SSL_CERT=client-
        cert.pem;SSL_CA=ca-cert.pem;CLIENT_IGNORE_SPACE=1"); // use an SSL
        connection to the server
            if (!db.open()) {
        db.setConnectOptions(); // clears the connect option string
                //
        ...
            }
            // ...
            // PostgreSQL connection
        db.setConnectOptions("requiressl=1"); // enable PostgreSQL SSL
        connections
            if (!db.open()) {
                db.setConnectOptions(); //
        clear options
                // ...
            }
            // ...
            // ODBC connection
        db.setConnectOptions("SQL_ATTR_ACCESS_MODE=SQL_MODE_READ_ONLY;SQL_ATTR_T
        RACE=SQL_OPT_TRACE_ON"); // set ODBC options
            if (!db.open()) {
        db.setConnectOptions(); // don't try to set this option
                // ...
        }
            }

        Refer to the client library documentation for more information about the
        different options.

        **See also** **connectOptions** ().
        """
        ...

    def setPort(self, p: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setPort

        **void QSqlDatabase::setPort(int port )**

        Sets the connection's port number to **port**. To have effect, the port
        number must be set **before** the connection is **opened** .
        Alternatively, you can **close** () the connection, set the port number,
        and call **open** () again..

        There is no default value.

        **See also** **port** (), **setUserName** (), **setPassword** (),
        **setHostName** (), **setDatabaseName** (), **setConnectOptions** (),
        and **open** ().
        """
        ...

    def setHostName(self, host: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setHostName

        **void QSqlDatabase::setHostName(const QString & host )**

        Sets the connection's host name to **host**. To have effect, the host
        name must be set **before** the connection is **opened** .
        Alternatively, you can **close** () the connection, set the host name,
        and call **open** () again.

        There is no default value.

        **See also** **hostName** (), **setUserName** (), **setPassword** (),
        **setDatabaseName** (), **setPort** (), **setConnectOptions** (), and
        **open** ().
        """
        ...

    def setPassword(self, password: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setPassword

        **void QSqlDatabase::setPassword(const QString & password )**

        Sets the connection's password to **password**. To have effect, the
        password must be set **before** the connection is **opened** .
        Alternatively, you can **close** () the connection, set the password,
        and call **open** () again.

        There is no default value.

        **Warning:** This function stores the password in plain text within Qt.
        Use the **open** () call that takes a password as parameter to avoid
        this behavior.

        **See also** **password** (), **setUserName** (), **setDatabaseName**
        (), **setHostName** (), **setPort** (), **setConnectOptions** (), and
        **open** ().
        """
        ...

    def setUserName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setUserName

        **void QSqlDatabase::setUserName(const QString & name )**

        Sets the connection's user name to **name**. To have effect, the user
        name must be set **before** the connection is **opened** .
        Alternatively, you can **close** () the connection, set the user name,
        and call **open** () again.

        There is no default value.

        **See also** **userName** (), **setDatabaseName** (), **setPassword**
        (), **setHostName** (), **setPort** (), **setConnectOptions** (), and
        **open** ().
        """
        ...

    def setDatabaseName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#setDatabaseName

        **void QSqlDatabase::setDatabaseName(const QString & name )**

        Sets the connection's database name to **name**. To have effect, the
        database name must be set **before** the connection is **opened** .
        Alternatively, you can **close** () the connection, set the database
        name, and call **open** () again.

        **Note:** The **database name** is not the **connection name**. The
        connection name must be passed to **addDatabase** () at connection
        object create time.

        For the QSQLITE driver, if the database name specified does not exist,
        then it will create the file for you unless the QSQLITE_OPEN_READONLY
        option is set.

        Additionally, **name** can be set to `":memory:"` which will create a
        temporary database which is only available for the lifetime of the
        application.

        For the QOCI (Oracle) driver, the database name is the TNS Service Name.

        For the QODBC driver, the **name** can either be a DSN, a DSN filename
        (in which case the file must have a `.dsn` extension), or a connection
        string.

        For example, Microsoft Access users can use the following connection
        string to open an `.mdb` file directly, instead of having to create a
        DSN entry in the ODBC manager:

        // ...
            **QSqlDatabase**  db = **QSqlDatabase**
        ::addDatabase("QODBC");
            db.setDatabaseName("DRIVER={Microsoft Access
        Driver (*.mdb, *.accdb)};FIL={MS Access};DBQ=myaccessfile.mdb");
            if
        (db.open()) {
                // success!
            }
            // ...

        There is no default value.

        **See also** **databaseName** (), **setUserName** (), **setPassword**
        (), **setHostName** (), **setPort** (), **setConnectOptions** (), and
        **open** ().
        """
        ...

    def rollback(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#rollback

        **bool QSqlDatabase::rollback()**

        Rolls back a transaction on the database, if the driver supports
        transactions and a **transaction** () has been started. Returns `true`
        if the operation succeeded. Otherwise it returns `false`.

        **Note:** For some databases, the rollback will fail and return `false`
        if there is an **active query**  using the database for a `SELECT`. Make
        the query **inactive**  before doing the rollback.

        Call **lastError** () to get information about errors.

        **See also** **QSqlQuery::isActive** (), **QSqlDriver::hasFeature** (),
        and **commit** ().
        """
        ...

    def commit(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#commit

        **bool QSqlDatabase::commit()**

        Commits a transaction to the database if the driver supports
        transactions and a **transaction** () has been started. Returns `true`
        if the operation succeeded. Otherwise it returns `false`.

        **Note:** For some databases, the commit will fail and return `false` if
        there is an **active query**  using the database for a `SELECT`. Make
        the query **inactive**  before doing the commit.

        Call **lastError** () to get information about errors.

        **See also** **QSqlQuery::isActive** (), **QSqlDriver::hasFeature** (),
        and **rollback** ().
        """
        ...

    def transaction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#transaction

        **bool QSqlDatabase::transaction()**

        Begins a transaction on the database if the driver supports
        transactions. Returns `true` if the operation succeeded. Otherwise it
        returns `false`.

        **See also** **QSqlDriver::hasFeature** (), **commit** (), and
        **rollback** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#isValid

        **bool QSqlDatabase::isValid() const**

        Returns `true` if the **QSqlDatabase**  has a valid driver.

        Example:

        **QSqlDatabase**  db;
            **qDebug** () << db.isValid();    // Returns
        false

            db = **QSqlDatabase** ::database("sales");
            **qDebug**
        () << db.isValid();    // Returns \\c true if "sales" connection exists
        **QSqlDatabase** ::removeDatabase("sales");
            **qDebug** () <<
        db.isValid();    // Returns false
        """
        ...

    def lastError(self) -> "QSqlError":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#lastError

        **QSqlError QSqlDatabase::lastError() const**

        Returns information about the last error that occurred on the database.

        Failures that occur in conjunction with an individual query are reported
        by **QSqlQuery::lastError** ().

        **See also** **QSqlError**  and **QSqlQuery::lastError** ().
        """
        ...

    def exec(self, query: str = ...) -> "QSqlQuery":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#exec

        **QSqlQuery QSqlDatabase::exec(const QString & query = QString())
        const**

        Executes a SQL statement on the database and returns a **QSqlQuery**
        object. Use **lastError** () to retrieve error information. If **query**
        is empty, an empty, invalid query is returned and **lastError** () is
        not affected.

        **See also** **QSqlQuery**  and **lastError** ().
        """
        ...

    def record(self, tablename: str) -> "QSqlRecord":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#record

        **QSqlRecord QSqlDatabase::record(const QString & tablename ) const**

        Returns a **QSqlRecord**  populated with the names of all the fields in
        the table (or view) called **tablename**. The order in which the fields
        appear in the record is undefined. If no such table (or view) exists, an
        empty record is returned.

        **Note:** Some drivers, such as the **QPSQL**  driver, may may require
        you to pass **tablename** in lower case if the table was not quoted when
        created. See the **Qt SQL driver**  documentation for more information.
        """
        ...

    def primaryIndex(self, tablename: str) -> "QSqlIndex":
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#primaryIndex

        **QSqlIndex QSqlDatabase::primaryIndex(const QString & tablename )
        const**

        Returns the primary index for table **tablename**. If no primary index
        exists, an empty **QSqlIndex**  is returned.

        **Note:** Some drivers, such as the **QPSQL**  driver, may may require
        you to pass **tablename** in lower case if the table was not quoted when
        created. See the **Qt SQL driver**  documentation for more information.

        **See also** **tables** () and **record** ().
        """
        ...

    def tables(self, type: "QSql.TableType" = ...) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#tables

        **QStringList QSqlDatabase::tables(QSql::TableType type = QSql::Tables)
        const**

        Returns a list of the database's tables, system tables and views, as
        specified by the parameter **type**.

        **See also** **primaryIndex** () and **record** ().
        """
        ...

    def isOpenError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#isOpenError

        **bool QSqlDatabase::isOpenError() const**

        Returns `true` if there was an error opening the database connection;
        otherwise returns `false`. Error information can be retrieved using the
        **lastError** () function.
        """
        ...

    def isOpen(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#isOpen

        **bool QSqlDatabase::isOpen() const**

        Returns `true` if the database connection is currently open; otherwise
        returns `false`.
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#close

        **void QSqlDatabase::close()**

        Closes the database connection, freeing any resources acquired, and
        invalidating any existing **QSqlQuery**  objects that are used with the
        database.

        This will also affect copies of this **QSqlDatabase**  object.

        **See also** **removeDatabase** ().
        """
        ...

    @typing.overload
    def open(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#open

        **bool QSqlDatabase::open()**

        Opens the database connection using the current connection values.
        Returns `true` on success; otherwise returns `false`. Error information
        can be retrieved using **lastError** ().

        **See also** **lastError** (), **setDatabaseName** (), **setUserName**
        (), **setPassword** (), **setHostName** (), **setPort** (), and
        **setConnectOptions** ().
        """
        ...

    @typing.overload
    def open(self, user: str, password: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqldatabase.html#open-1

        **bool QSqlDatabase::open(const QString & user , const QString &
        password )**

        This is an overloaded function.

        Opens the database connection using the given **user** name and
        **password**. Returns `true` on success; otherwise returns `false`.
        Error information can be retrieved using the **lastError** () function.

        This function does not store the password it is given. Instead, the
        password is passed directly to the driver for opening the connection and
        it is then discarded.

        **See also** **lastError** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtQml
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickImageProvider(QtQml.QQmlImageProviderBase):
    """
    https://doc.qt.io/qt-6/qquickimageprovider.html

    **Detailed Description**

    QQuickImageProvider is used to provide advanced image loading features in
    QML applications. It allows images in QML to be:

    * Loaded using QPixmaps rather than actual image files
      * Loaded
    asynchronously in a separate thread

    To specify that an image should be loaded by an image provider, use the
    **"image:"** scheme for the URL source of the image, followed by the
    identifiers of the image provider and the requested image. For example:

    **Image**  { source: "image://myimageprovider/image.png" }

    This specifies that the image should be loaded by the image provider named
    "myimageprovider", and the image to be loaded is named "image.png". The QML
    engine invokes the appropriate image provider according to the providers
    that have been registered through **QQmlEngine::addImageProvider** ().

    Note that the identifiers are case-insensitive, but the rest of the URL will
    be passed on with preserved case. For example, the below snippet would still
    specify that the image is loaded by the image provider named
    "myimageprovider", but it would request a different image than the above
    snippet ("Image.png" instead of "image.png").

    **Image**  { source: "image://MyImageProvider/Image.png" }

    If you want the rest of the URL to be case insensitive, you will have to
    take care of that yourself inside your image provider.

    **An Example**

    Here are two images. Their `source` values indicate they should be loaded by
    an image provider named "colors", and the images to be loaded are "yellow"
    and "red", respectively:

    **Column**  {
            **Image**  { source: "image://colors/yellow" }
    **Image**  { source: "image://colors/red" }
        }

    When these images are loaded by QML, it looks for a matching image provider
    and calls its **requestImage** () or **requestPixmap** () method (depending
    on its **imageType** ()) to load the image. The method is called with the
    `id` parameter set to "yellow" for the first image, and "red" for the
    second.

    Here is an image provider implementation that can load the images requested
    by the above QML. This implementation dynamically generates **QPixmap**
    images that are filled with the requested color:

    class ColorImageProvider : public **QQuickImageProvider**
        {
        public:
    ColorImageProvider()
                       : **QQuickImageProvider**
    (**QQuickImageProvider** ::Pixmap)
            {
            }
    **QPixmap**  requestPixmap(const **QString**  &id, **QSize**  *size, const
    **QSize**  &requestedSize) override
            {
               int width = 100;
    int height = 50;

               if (size)
                  *size = **QSize**
    (width, height);
               **QPixmap**  pixmap(requestedSize.width() > 0 ?
    requestedSize.width() : width,
    requestedSize.height() > 0 ? requestedSize.height() : height);
    pixmap.fill(**QColor** (id).rgba());
               return pixmap;
            }
    };

    To make this provider accessible to QML, it is registered with the QML
    engine with a "colors" identifier:

    int main(int argc, char *argv[])
        {

            **QQuickView**  view;
    **QQmlEngine**  *engine = view.engine();
    engine->addImageProvider(QLatin1String("colors"), new ColorImageProvider);
    view.setSource(**QUrl** ::fromLocalFile(**QStringLiteral** ("imageprovider-
    example.qml")));
            view.show();
            return app.exec();
        }

    Now the images can be successfully loaded in QML:

    ![](images/imageprovider.png)

    See the **Image Provider Example**  for the complete implementation. Note
    that the example registers the provider via a **plugin**  instead of
    registering it in the application `main()` function as shown above.

    **Asynchronous Image Loading**

    Image providers that support **QImage**  or Texture loading automatically
    include support for asychronous loading of images. To enable asynchronous
    loading for an image source, set the `asynchronous` property to `true` for
    the relevant **Image**  or **BorderImage**  object. When this is enabled,
    the image request to the provider is run in a low priority thread, allowing
    image loading to be executed in the background, and reducing the performance
    impact on the user interface.

    To force asynchronous image loading, even for image sources that do not have
    the `asynchronous` property set to `true`, you may pass the
    `QQmlImageProviderBase::ForceAsynchronousImageLoading` flag to the image
    provider constructor. This ensures that all image requests for the provider
    are handled in a separate thread.

    Asynchronous loading for image providers that provide **QPixmap**  is only
    supported in platforms that have the ThreadedPixmaps feature, in platforms
    where pixmaps can only be created in the main thread (i.e. ThreadedPixmaps
    is not supported) if **asynchronous**  is set to `true`, the value is
    ignored and the image is loaded synchronously.

    Asynchronous image loading for providers of type other than ImageResponse
    are executed on a single thread per engine basis. That means that a slow
    image provider will block the loading of any other request. To avoid that we
    suggest using **QQuickAsyncImageProvider**  and implement threading on the
    provider side via a `QThreadPool` or similar. See the **Image Response
    Provider Example**  for a complete implementation.

    **Image Caching**

    Images returned by a QQuickImageProvider are automatically cached, similar
    to any image loaded by the QML engine. When an image with a "image://"
    prefix is loaded from cache, **requestImage** () and **requestPixmap** ()
    will not be called for the relevant image provider. If an image should
    always be fetched from the image provider, and should not be cached at all,
    set the `cache` property to `false` for the relevant **Image**  or
    **BorderImage**  object.

    **See also** **QQmlEngine::addImageProvider** ().
    """

    def __init__(
        self,
        type: QtQml.QQmlImageProviderBase.ImageType,
        flags: QtQml.QQmlImageProviderBase.Flag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#QQuickImageProvider

        **QQuickImageProvider::QQuickImageProvider(QQmlImageProviderBase::ImageT
        ype type , QQmlImageProviderBase::Flags flags = Flags())**

        Creates an image provider that will provide images of the given **type**
        and behave according to the given **flags**.
        """
        ...

    def requestTexture(
        self, id: str, requestedSize: QtCore.QSize
    ) -> typing.Tuple[QQuickTextureFactory, QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#requestTexture

        **[virtual] QQuickTextureFactory
        *QQuickImageProvider::requestTexture(const QString & id , QSize * size ,
        const QSize & requestedSize )**

        Implement this method to return the texture with **id**. The default
        implementation returns `nullptr`.

        The **id** is the requested image source, with the "image:" scheme and
        provider identifier removed. For example, if the image **source**  was
        "image://myprovider/icons/home", the given **id** would be "icons/home".

        The **requestedSize** corresponds to the **Image::sourceSize**
        requested by an Image item. If **requestedSize** is a valid size, the
        image returned should be of that size.

        In all cases, **size** must be set to the original size of the image.
        This is used to set the **width**  and **height**  of the relevant
        **Image**  if these values have not been set explicitly.

        **Note:** this method may be called by multiple threads, so ensure the
        implementation of this method is reentrant.
        """
        ...

    def requestPixmap(
        self, id: str, requestedSize: QtCore.QSize
    ) -> typing.Tuple[QtGui.QPixmap, QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#requestPixmap

        **[virtual] QPixmap QQuickImageProvider::requestPixmap(const QString &
        id , QSize * size , const QSize & requestedSize )**

        Implement this method to return the pixmap with **id**. The default
        implementation returns an empty pixmap.

        The **id** is the requested image source, with the "image:" scheme and
        provider identifier removed. For example, if the image **source**  was
        "image://myprovider/icons/home", the given **id** would be "icons/home".

        The **requestedSize** corresponds to the **Image::sourceSize**
        requested by an Image item. If **requestedSize** is a valid size, the
        image returned should be of that size.

        In all cases, **size** must be set to the original size of the image.
        This is used to set the **width**  and **height**  of the relevant
        **Image**  if these values have not been set explicitly.

        **Note:** this method may be called by multiple threads, so ensure the
        implementation of this method is reentrant.
        """
        ...

    def requestImage(
        self, id: str, requestedSize: QtCore.QSize
    ) -> typing.Tuple[QtGui.QImage, QtCore.QSize]:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#requestImage

        **[virtual] QImage QQuickImageProvider::requestImage(const QString & id
        , QSize * size , const QSize & requestedSize )**

        Implement this method to return the image with **id**. The default
        implementation returns an empty image.

        The **id** is the requested image source, with the "image:" scheme and
        provider identifier removed. For example, if the image **source**  was
        "image://myprovider/icons/home", the given **id** would be "icons/home".

        The **requestedSize** corresponds to the **Image::sourceSize**
        requested by an Image item. If **requestedSize** is a valid size, the
        image returned should be of that size.

        In all cases, **size** must be set to the original size of the image.
        This is used to set the **width**  and **height**  of the relevant
        **Image**  if these values have not been set explicitly.

        **Note:** this method may be called by multiple threads, so ensure the
        implementation of this method is reentrant.
        """
        ...

    def flags(self) -> QtQml.QQmlImageProviderBase.Flag:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#flags

        **[override virtual] QQmlImageProviderBase::Flags
        QQuickImageProvider::flags() const**

        Reimplements: **QQmlImageProviderBase::flags() const** .

        Returns the flags set for this provider.
        """
        ...

    def imageType(self) -> QtQml.QQmlImageProviderBase.ImageType:
        """
        https://doc.qt.io/qt-6/qquickimageprovider.html#imageType

        **[override virtual] QQmlImageProviderBase::ImageType
        QQuickImageProvider::imageType() const**

        Reimplements: **QQmlImageProviderBase::imageType() const** .

        Returns the image type supported by this provider.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick3D import *
import enum


class QQuick3DGeometry(QQuick3DObject):
    """
    https://doc.qt.io/qt-6/qquick3dgeometry.html

    **Detailed Description**

    The QQuick3DGeometry can be used to specify custom geometry for a Model in
    the Qt Quick 3D scene.

    While not strictly required, the typical usage is to inherit from this
    class. The subclass is then exposed to QML by registering it to the type
    system. The **geometry**  property of a Model can then be set to reference
    an instance of the registered type.

    The high-level structure of such a class is typically similar to the
    following:

    class CustomGeometry : public QQuick3DGeometry
        {
        public:
    CustomGeometry() { rebuildGeometry(); }

            void setSomething() {
    // Change relevant internal data.
               // ...

               // Then
    rebuild the vertex and index data and pass it to QQuick3DGeometry.
    rebuildGeometry();

               // Finally, trigger an update. This is
    relevant in case nothing else
               // is changing in the scene; this
    way we make sure a new frame will
               // be rendered.
    update();
            }

        private:
            void rebuildGeometry()
    {
                **QByteArray**  vertices;
                **QByteArray**  indices;
    ...
                setPrimitiveType(Lines);
    setVertexBuffer(vertices);
                setIndexBuffer(indices);
    setStride(3 * sizeof(float)); // e.g. when having 3 components per vertex
    setBounds(...); // minimum and maximum extents, for picking
    addAttribute(PositionSemantic, 0, F32Type);
                ...
            }
        };

    This class can then be registered as a QML type and used with **Model** .

    In Qt 5 type registration happened with **qmlRegisterType** :

    qmlRegisterType<CustomGeometry>("Example", 1, 0, "CustomGeometry");

    In Qt 6 the default approach is to use automatic registration with the help
    of the build system. Instead of calling **qmlRegisterType** , the `.pro`
    file can now contain:

    CONFIG += qmltypes
        QML_IMPORT_NAME = Example
    QML_IMPORT_MAJOR_VERSION = 1

    With CMake, automatic registration is the default behavior, so no special
    settings are needed beyond basic QML module setup:

    qt_add_qml_module(application
            URI Example
            VERSION 1.0
        )

    The class implementation should add **QML_NAMED_ELEMENT** :

    class CustomGeometry : public QQuick3DGeometry
        {
            Q_OBJECT
    QML_NAMED_ELEMENT(CustomGeometry)
            ...
        };

    The QML code can then use the custom type:

    import Example 1.0

        Model {
            id: customModel
    geometry: CustomGeometry {
            }
        }

    At minimum, a custom geometry should have the following specified:

    * vertex data,
      * vertex stride,
      * primitive type,
      * an attribute with
    PositionSemantic.

    These are sufficient to render the mesh. For indexed drawing, the index
    buffer data and an attribute with IndexSemantic needs to be specified as
    well. In order to support picking (input), the class must specify the
    bounding volume using **setBounds** (). For proper lighting, an attribute
    with NormalSemantic is needed. When the material uses texturing, at least
    one set of UV coordinates must be provided and described in an
    TexCoord0Semantic or TexCoord1Semantic attribute. Some materials may require
    tangents and binormals as well.

    As a concrete, minimal example, the following class would provide geometry
    for a single triangle:

    class ExampleGeometry : public QQuick3DGeometry
        {
            Q_OBJECT
    QML_NAMED_ELEMENT(ExampleGeometry)

        public:
    ExampleGeometry();

        private:
            void updateData();
        };
    ExampleGeometry::ExampleGeometry()
        {
            updateData();
        }
    void ExampleGeometry::updateData()
        {
            **QByteArray**  v;
    v.resize(3 * 3 * sizeof(float));
            float *p = reinterpret_cast<float
    *>(v.data());

            // a triangle, front face = counter-clockwise
    *p++ = -1.0f; *p++ = -1.0f; *p++ = 0.0f;
            *p++ = 1.0f; *p++ = -1.0f;
    *p++ = 0.0f;
            *p++ = 0.0f; *p++ = 1.0f; *p++ = 0.0f;
    setVertexData(v);
            setStride(3 * sizeof(float));
    setPrimitiveType(QQuick3DGeometry::PrimitiveType::Triangles);
    addAttribute(QQuick3DGeometry::Attribute::PositionSemantic,
    0,
                         QQuick3DGeometry::Attribute::F32Type);
        }

    Depending on the lighting in the scene, the result of referencing this
    geometry from a Model:

    ![](images/customgeometry.jpg)

    **Note:** Vertex data is expected to follow OpenGL conventions. This means
    the data must be provided with the assumption that the Y axis is pointing up
    in the normalized device coordinate system, and that front faces have a
    counter clockwise winding.

    **See also** **Model**  and **Geometry** .
    """

    class PrimitiveType(enum.Enum):
        Points: QQuick3DGeometry = ...
        LineStrip: QQuick3DGeometry = ...
        Lines: QQuick3DGeometry = ...
        TriangleStrip: QQuick3DGeometry = ...
        TriangleFan: QQuick3DGeometry = ...
        Triangles: QQuick3DGeometry = ...

    class Attribute(PyQt6.sip.simplewrapper):
        class ComponentType(enum.Enum):
            U16Type: QQuick3DGeometry = ...
            U32Type: QQuick3DGeometry = ...
            F32Type: QQuick3DGeometry = ...
            I32Type: QQuick3DGeometry = ...

        class Semantic(enum.Enum):
            IndexSemantic: QQuick3DGeometry = ...
            PositionSemantic: QQuick3DGeometry = ...
            NormalSemantic: QQuick3DGeometry = ...
            TexCoordSemantic: QQuick3DGeometry = ...
            TangentSemantic: QQuick3DGeometry = ...
            BinormalSemantic: QQuick3DGeometry = ...
            JointSemantic: QQuick3DGeometry = ...
            WeightSemantic: QQuick3DGeometry = ...
            ColorSemantic: QQuick3DGeometry = ...
            TargetPositionSemantic: QQuick3DGeometry = ...
            TargetNormalSemantic: QQuick3DGeometry = ...
            TargetTangentSemantic: QQuick3DGeometry = ...
            TargetBinormalSemantic: QQuick3DGeometry = ...
            TexCoord1Semantic: QQuick3DGeometry = ...
            TexCoord0Semantic: QQuick3DGeometry = ...

        componentType = ...
        offset: int = ...
        semantic = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QQuick3DGeometry.Attribute") -> None:
            ...

    def __init__(self, parent: typing.Optional[QQuick3DObject] = ...) -> None:
        ...

    def indexData(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#indexData

        **QByteArray QQuick3DGeometry::indexData() const**

        Returns the index buffer data.

        **See also** **setIndexData** ().
        """
        ...

    def vertexData(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#vertexData

        **QByteArray QQuick3DGeometry::vertexData() const**

        Returns the vertex buffer data set by **setVertexData** .

        **See also** **setVertexData** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#clear

        **void QQuick3DGeometry::clear()**

        Resets the geometry to its initial state, clearing previously set vertex
        and index data as well as attributes.
        """
        ...

    @typing.overload
    def addAttribute(
        self,
        semantic: "QQuick3DGeometry.Attribute.Semantic",
        offset: int,
        componentType: "QQuick3DGeometry.Attribute.ComponentType",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#addAttribute

        **void QQuick3DGeometry::addAttribute(Attribute::Semantic semantic , int
        offset , Attribute::ComponentType componentType )**

        Adds vertex attribute description. Each attribute has a **semantic** ,
        which specifies the usage of the attribute and the number of components
        it has, an **offset** from the beginning to the vertex to the attribute
        location inside a vertex and a **componentType** specifying the datatype
        and size of the attribute.

        The semantic can be one of the following:

        ConstantDescription
        `PositionSemantic`The attribute is a position. 3
        components: **x** , **y** , and **z**
        `NormalSemantic`The attribute is
        a normal vector. 3 components: **x** , **y** , and **z**
        `TexCoord0Semantic`The attribute is a texture coordinate. 2 components:
        **u** and **v**
        `TexCoord1Semantic`The attribute is a texture
        coordinate. 2 components: **u** and **v**
        `TangentSemantic`The
        attribute is a tangent vector. 3 components: **x** , **y** , and **z**
        `BinormalSemantic`The attribute is a binormal vector. 3 components:
        **x** , **y** , and **z**
        `JointSemantic`The attribute is a joint
        index vector for **skinning** . 4 components: joint index 1-4
        `WeightSemantic`The attribute is a weight vector for **skinning** . 4
        components: joint weight 1-4
        `ColorSemantic`The attribute is a vertex
        color vector. 4 components: **r** , **g** , **b** , and **a**
        `TargetPositionSemantic`The attribute is a position for the first
        **morph target** . 3 components: **x** , **y** , and **z**
        `TargetNormalSemantic`The attribute is a normal vector for the first
        **morph target** . 3 components: **x** , **y** , and **z**
        `TargetTangentSemantic`The attribute is a tangent vector for the first
        **morph target** . 3 components: **x** , **y** , and **z**
        `TargetBinormalSemantic`The attribute is a binormal vector for the first
        **morph target** . 3 components: **x** , **y** , and **z**

        In addition, **semantic** can be `IndexSemantic`. In this case the
        attribute does not represent an entry in the vertex buffer, but rather
        describes the index data in the index buffer. Since there is always just
        one index per vertex, **offset** makes no sense for the index buffer,
        and should be left at zero.

        The component type can be one of the following:

        ConstantDescription
        `U16Type`The attribute is an unsigned 16-bit
        integer.
        `U32Type`The attribute is an unsigned 32-bit integer.
        `I32Type`The attribute is a signed 32-bit integer.
        `F32Type`The
        attribute is a single-precision float.

        **Note:** The joint index data is typically `I32Type`. `F32Type` is also
        supported in order to enable functioning with APIs, such as OpenGL ES
        2.0, that do not support integer vertex input attributes.
        """
        ...

    @typing.overload
    def addAttribute(self, att: "QQuick3DGeometry.Attribute") -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#addAttribute-1

        **void QQuick3DGeometry::addAttribute(const QQuick3DGeometry::Attribute
        & attribute )**

        This is an overloaded function.

        Adds vertex attribute description. Each attribute has a semantic, which
        specifies the usage of the attribute and the number of components it
        has, an offset from the beginning to the vertex to the attribute
        location inside a vertex and a componentType specifying the datatype and
        size of the attribute.
        """
        ...

    def setPrimitiveType(self, type: "QQuick3DGeometry.PrimitiveType") -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setPrimitiveType

        **void
        QQuick3DGeometry::setPrimitiveType(QQuick3DGeometry::PrimitiveType type
        )**

        Sets the primitive type used for rendering to **type**.

        ConstantDescription
        `Points`The primitives are points.
        `LineStrip`The primitives are lines in a strip.
        `Lines`The primitives
        are lines in a list.
        `TriangleStrip`The primitives are triangles in a
        strip.
        `TriangleFan`The primitives are triangles in a fan. Be aware
        that triangle fans may not be supported at run time, depending on the
        underlying graphics API.
        `Triangles`The primitives are triangles in a
        list.

        The initial value is `Triangles`.

        **Note:** Be aware that triangle fans (TriangleFan) may not be supported
        at run time, depending on the underlying graphics API. For example, with
        Direct 3D this topology will not be functional at all.

        **Note:** The point size for Points and the line width for Lines and
        LineStrip are controlled by the **material** . Be aware however that
        sizes other than 1 may not be supported at run time, depending on the
        underlying graphics API.

        **See also** **primitiveType** ().
        """
        ...

    def setBounds(self, min: QtGui.QVector3D, max: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setBounds

        **void QQuick3DGeometry::setBounds(const QVector3D & min , const
        QVector3D & max )**

        Sets the bounding volume of the geometry to the cube defined by the
        points **min** and **max**. This is used for **picking** .
        """
        ...

    def setStride(self, stride: int) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setStride

        **void QQuick3DGeometry::setStride(int stride )**

        Sets the stride of the vertex buffer to **stride** , measured in bytes.
        This is the distance between two consecutive vertices in the buffer.

        For example, a tightly packed, interleaved vertex buffer for a geometry
        using `PositionSemantic`, `IndexSemantic`, and `ColorSemantic` will have
        a stride of `28` (Seven floats in total: Three for position, four for
        color, and none for indexes, which do not go in the vertex buffer.)

        **Note:****QQuick3DGeometry**  expects, and works only with, vertex data
        with an interleaved attribute layout.

        **See also** **stride** () and **addAttribute** .
        """
        ...

    @typing.overload
    def setIndexData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setIndexData

        **void QQuick3DGeometry::setIndexData(const QByteArray & data )**

        Sets the index buffer to **data**. To use indexed drawing, add an
        attribute with `IndexSemantic`

        **See also** **indexData** () and **addAttribute** .
        """
        ...

    @typing.overload
    def setIndexData(self, offset: int, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setIndexData-1

        **void QQuick3DGeometry::setIndexData(int offset , const QByteArray &
        data )**

        This is an overloaded function.

        Updates a subset of the index buffer. **offset** specifies the offset in
        bytes, **data** specifies the size and the data.

        This function will not resize the buffer. If `offset + data.size()` is
        greater than the current size of the buffer, the overshooting data will
        be ignored.

        **Note:** The partial update functions for vertex and index data do not
        offer any guarantee on how such changes are implemented internally.
        Depending on the underlying implementation, even partial changes may
        lead to updating the entire graphics resource.
        """
        ...

    @typing.overload
    def setVertexData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setVertexData

        **void QQuick3DGeometry::setVertexData(const QByteArray & data )**

        Sets the vertex buffer **data**. The buffer should hold all the vertex
        data packed in the array, as described by the attribute definitions.
        Note that this does not include attributes with `IndexSemantic`, which
        belong in the index buffer.

        **See also** **vertexData** (), **addAttribute** , **setStride** , and
        **setIndexData** .
        """
        ...

    @typing.overload
    def setVertexData(self, offset: int, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#setVertexData-1

        **void QQuick3DGeometry::setVertexData(int offset , const QByteArray &
        data )**

        This is an overloaded function.

        Updates a subset of the vertex buffer. **offset** specifies the offset
        in bytes, **data** specifies the size and the data.

        This function will not resize the buffer. If `offset + data.size()` is
        greater than the current size of the buffer, the overshooting data will
        be ignored.

        **Note:** The partial update functions for vertex and index data do not
        offer any guarantee on how such changes are implemented internally.
        Depending on the underlying implementation, even partial changes may
        lead to updating the entire graphics resource.
        """
        ...

    def stride(self) -> int:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#stride

        **int QQuick3DGeometry::stride() const**

        Returns the byte stride of the vertex buffer.

        **See also** **setStride** .
        """
        ...

    def boundsMax(self) -> QtGui.QVector3D:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#boundsMax

        **QVector3D QQuick3DGeometry::boundsMax() const**

        Returns the maximum coordinate of the bounding volume.

        **See also** **setBounds** .
        """
        ...

    def boundsMin(self) -> QtGui.QVector3D:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#boundsMin

        **QVector3D QQuick3DGeometry::boundsMin() const**

        Returns the minimum coordinate of the bounding volume.

        **See also** **setBounds** .
        """
        ...

    def primitiveType(self) -> "QQuick3DGeometry.PrimitiveType":
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#primitiveType

        **QQuick3DGeometry::PrimitiveType QQuick3DGeometry::primitiveType()
        const**

        Returns the primitive type used when rendering. The default is
        `Triangles`.

        **See also** **setPrimitiveType** .
        """
        ...

    def attribute(self, index: int) -> "QQuick3DGeometry.Attribute":
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#attribute

        **QQuick3DGeometry::Attribute QQuick3DGeometry::attribute(int index )
        const**

        Returns attribute definition number **index**

        The attribute definitions are numbered from 0 to `attributeCount() - 1`
        """
        ...

    def attributeCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qquick3dgeometry.html#attributeCount

        **int QQuick3DGeometry::attributeCount() const**

        Returns the number of attributes defined for this geometry.

        **See also** **attribute** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtBluetooth import *
import enum


class QBluetoothServiceInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbluetoothserviceinfo.html

    **Detailed Description**

    QBluetoothServiceInfo provides information about a service offered by a
    Bluetooth device. In addition it can be used to register new services on the
    local device. Note that such a registration only affects the Bluetooth SDP
    entries. Any server listening for incoming connections (e.g an RFCOMM
    server) must be started before **registerService** () is called.
    Deregistration must happen in the reverse order.

    QBluetoothServiceInfo is not a value type in the traditional sense. All
    copies of the same service info object share the same data as they do not
    detach upon changing them. This ensures that two copies can (de)register the
    same Bluetooth service.

    On iOS, this class cannot be used because the platform does not expose an
    API which may permit access to QBluetoothServiceInfo related features.
    """

    class Protocol(enum.Enum):
        UnknownProtocol: QBluetoothServiceInfo = ...
        L2capProtocol: QBluetoothServiceInfo = ...
        RfcommProtocol: QBluetoothServiceInfo = ...

    class AttributeId(enum.Enum):
        ServiceRecordHandle: QBluetoothServiceInfo = ...
        ServiceClassIds: QBluetoothServiceInfo = ...
        ServiceRecordState: QBluetoothServiceInfo = ...
        ServiceId: QBluetoothServiceInfo = ...
        ProtocolDescriptorList: QBluetoothServiceInfo = ...
        BrowseGroupList: QBluetoothServiceInfo = ...
        LanguageBaseAttributeIdList: QBluetoothServiceInfo = ...
        ServiceInfoTimeToLive: QBluetoothServiceInfo = ...
        ServiceAvailability: QBluetoothServiceInfo = ...
        BluetoothProfileDescriptorList: QBluetoothServiceInfo = ...
        DocumentationUrl: QBluetoothServiceInfo = ...
        ClientExecutableUrl: QBluetoothServiceInfo = ...
        IconUrl: QBluetoothServiceInfo = ...
        AdditionalProtocolDescriptorList: QBluetoothServiceInfo = ...
        PrimaryLanguageBase: QBluetoothServiceInfo = ...
        ServiceName: QBluetoothServiceInfo = ...
        ServiceDescription: QBluetoothServiceInfo = ...
        ServiceProvider: QBluetoothServiceInfo = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#QBluetoothServiceInfo

        **QBluetoothServiceInfo::QBluetoothServiceInfo()**

        Construct a new invalid QBluetoothServiceInfo;
        """
        ...

    @typing.overload
    def __init__(self, other: "QBluetoothServiceInfo") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#QBluetoothServiceInfo-
        1

        **QBluetoothServiceInfo::QBluetoothServiceInfo(const
        QBluetoothServiceInfo & other )**

        Construct a new QBluetoothServiceInfo that is a copy of **other**.

        The two copies continue to share the same underlying data which does not
        detach upon write.
        """
        ...

    def serviceClassUuids(self) -> typing.List["QBluetoothUuid"]:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceClassUuids

        **QList<QBluetoothUuid> QBluetoothServiceInfo::serviceClassUuids()
        const**

        Returns a list of UUIDs describing the service classes that this service
        conforms to.

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceClassIds**
        ).value<**QBluetoothServiceInfo::Sequence** >() and subsequently
        iterating over its **QBluetoothUuid**  entries.

        **See also** **attribute** ().
        """
        ...

    def serviceUuid(self) -> "QBluetoothUuid":
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceUuid

        **QBluetoothUuid QBluetoothServiceInfo::serviceUuid() const**

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceId**
        ).value<**QBluetoothUuid** >().

        Returns the custom UUID of the service. This UUID may be null. UUIDs
        based on **Bluetooth SIG standards**  should be retrieved via
        **serviceClassUuids** ().

        **See also** **setServiceUuid** () and **attribute** ().
        """
        ...

    def setServiceUuid(self, uuid: "QBluetoothUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setServiceUuid

        **void QBluetoothServiceInfo::setServiceUuid(const QBluetoothUuid & uuid
        )**

        This is a convenience function. It is equivalent to calling
        **setAttribute** (**QBluetoothServiceInfo::ServiceId** , uuid).

        Sets the custom service UUID to **uuid**. This function should not be
        used to set a standardized service UUID.

        **See also** **serviceUuid** () and **setAttribute** ().
        """
        ...

    def serviceAvailability(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceAvailability

        **quint8 QBluetoothServiceInfo::serviceAvailability() const**

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceAvailability** ).toUInt().

        Returns the availability of the service.

        **See also** **setServiceAvailability** () and **attribute** ().
        """
        ...

    def setServiceAvailability(self, availability: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setServiceAvailability

        **void QBluetoothServiceInfo::setServiceAvailability(quint8 availability
        )**

        This is a convenience function. It is equivalent to calling
        **setAttribute** (**QBluetoothServiceInfo::ServiceAvailability** ,
        availability).

        Sets the availabiltiy of the service to **availability**.

        **See also** **serviceAvailability** () and **setAttribute** ().
        """
        ...

    def serviceProvider(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceProvider

        **QString QBluetoothServiceInfo::serviceProvider() const**

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceProvider** ).toString().

        Returns the service provider in the primary language.

        **See also** **setServiceProvider** () and **attribute** ().
        """
        ...

    def setServiceProvider(self, provider: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setServiceProvider

        **void QBluetoothServiceInfo::setServiceProvider(const QString &
        provider )**

        This is a convenience function. It is equivalent to calling
        **setAttribute** (**QBluetoothServiceInfo::ServiceProvider** ,
        provider).

        Sets the service provider in the primary language to **provider**.

        **See also** **serviceProvider** () and **setAttribute** ().
        """
        ...

    def serviceDescription(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceDescription

        **QString QBluetoothServiceInfo::serviceDescription() const**

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceDescription** ).toString().

        Returns the service description in the primary language.

        **See also** **setServiceDescription** () and **attribute** ().
        """
        ...

    def setServiceDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setServiceDescription

        **void QBluetoothServiceInfo::setServiceDescription(const QString &
        description )**

        This is a convenience function. It is equivalent to calling
        **setAttribute** (**QBluetoothServiceInfo::ServiceDescription** ,
        description).

        Sets the service description in the primary language to **description**.

        **See also** **serviceDescription** () and **setAttribute** ().
        """
        ...

    def serviceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serviceName

        **QString QBluetoothServiceInfo::serviceName() const**

        This is a convenience function. It is equivalent to calling
        attribute(**QBluetoothServiceInfo::ServiceName** ).toString().

        Returns the service name in the primary language.

        **See also** **setServiceName** () and **attribute** ().
        """
        ...

    def setServiceName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setServiceName

        **void QBluetoothServiceInfo::setServiceName(const QString & name )**

        This is a convenience function. It is equivalent to calling
        **setAttribute** (**QBluetoothServiceInfo::ServiceName** , name).

        Sets the service name in the primary language to **name**.

        **See also** **serviceName** () and **setAttribute** ().
        """
        ...

    @typing.overload
    def setAttribute(self, attributeId: int, value: "QBluetoothUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setAttribute

        **void QBluetoothServiceInfo::setAttribute(quint16 attributeId , const
        QVariant & value )**

        Sets the attribute identified by **attributeId** to **value**.

        If the service information is already registered with the platform's SDP
        database, the database entry will not be updated until
        **registerService** () was called again.

        **Note:** If an attribute expectes a byte-encoded value (e.g. Bluetooth
        HID services), it should be set as **QByteArray** .

        **See also** **attribute** (), **isRegistered** (), and
        **registerService** ().
        """
        ...

    @typing.overload
    def setAttribute(
        self, attributeId: int, value: typing.Iterable[typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setAttribute-1

        **void QBluetoothServiceInfo::setAttribute(quint16 attributeId , const
        QBluetoothUuid & value )**

        This is a convenience function.

        Sets the attribute identified by **attributeId** to **value**.

        If the service information is already registered with the platform's SDP
        database, the database entry will not be updated until
        **registerService** () was called again.
        """
        ...

    @typing.overload
    def setAttribute(self, attributeId: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setAttribute-2

        **void QBluetoothServiceInfo::setAttribute(quint16 attributeId , const
        QBluetoothServiceInfo::Sequence & value )**

        This is a convenience function.

        Sets the attribute identified by **attributeId** to **value**.

        If the service information is already registered with the platform's SDP
        database, the database entry will not be updated until
        **registerService** () was called again.
        """
        ...

    def unregisterService(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#unregisterService

        **bool QBluetoothServiceInfo::unregisterService()**

        Unregisters this service with the platform's Service Discovery Protocol
        (SDP) implementation. After this, the service will no longer be findable
        by other devices through service discovery.

        Returns true if the service is successfully unregistered, otherwise
        returns false.
        """
        ...

    def registerService(self, localAdapter: QBluetoothAddress = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#registerService

        **bool QBluetoothServiceInfo::registerService(const QBluetoothAddress &
        localAdapter = QBluetoothAddress())**

        Registers this service with the platform's Service Discovery Protocol
        (SDP) implementation, making it findable by other devices when they
        perform service discovery. Returns true if the service is successfully
        registered, otherwise returns false. Once registered changes to the
        record cannot be made. The service must be unregistered and registered
        again with the changes.

        The **localAdapter** parameter determines the local Bluetooth adapter
        under which the service should be registered. If **localAdapter** is
        `null` the default Bluetooth adapter will be used. If this service info
        object is already registered via a local adapter and this is function is
        called using a different local adapter, the previous registration is
        removed and the service reregistered using the new adapter.
        """
        ...

    def isRegistered(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#isRegistered

        **bool QBluetoothServiceInfo::isRegistered() const**

        Returns true if the service information is registered with the
        platform's Service Discovery Protocol (SDP) implementation, otherwise
        returns false.
        """
        ...

    def protocolDescriptor(
        self, protocol: "QBluetoothUuid.ProtocolUuid"
    ) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#protocolDescriptor

        **QBluetoothServiceInfo::Sequence
        QBluetoothServiceInfo::protocolDescriptor(QBluetoothUuid::ProtocolUuid
        protocol ) const**

        Returns the protocol parameters as a **QBluetoothServiceInfo::Sequence**
        for protocol **protocol**.

        An empty **QBluetoothServiceInfo::Sequence**  is returned if
        **protocol** is not supported.
        """
        ...

    def serverChannel(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#serverChannel

        **int QBluetoothServiceInfo::serverChannel() const**

        This is a convenience function. Returns the server channel for services
        which support the RFCOMM protocol, otherwise returns -1.

        This function is equivalent to extracting the information from
        **QBluetoothServiceInfo::Sequence**  returned by
        **QBluetoothServiceInfo::attribute**
        (QBluetootherServiceInfo::ProtocolDescriptorList).
        """
        ...

    def protocolServiceMultiplexer(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#protocolServiceMultipl
        exer

        **int QBluetoothServiceInfo::protocolServiceMultiplexer() const**

        This is a convenience function. Returns the protocol/service multiplexer
        for services which support the L2CAP protocol, otherwise returns -1.

        This function is equivalent to extracting the information from
        **QBluetoothServiceInfo::Sequence**  returned by
        **QBluetoothServiceInfo::attribute**
        (**QBluetoothServiceInfo::ProtocolDescriptorList** ).
        """
        ...

    def socketProtocol(self) -> "QBluetoothServiceInfo.Protocol":
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#socketProtocol

        **QBluetoothServiceInfo::Protocol
        QBluetoothServiceInfo::socketProtocol() const**

        Returns the protocol that the **QBluetoothServiceInfo**  object uses.
        """
        ...

    def removeAttribute(self, attributeId: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#removeAttribute

        **void QBluetoothServiceInfo::removeAttribute(quint16 attributeId )**

        Removes the attribute **attributeId** from the **QBluetoothServiceInfo**
        object.

        If the service information is already registered with the platforms SDP
        database, the database entry will not be updated until
        **registerService** () was called again.
        """
        ...

    def contains(self, attributeId: int) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#contains

        **bool QBluetoothServiceInfo::contains(quint16 attributeId ) const**

        Returns true if the **QBluetoothServiceInfo**  object contains the
        attribute **attributeId** , otherwise returns false.
        """
        ...

    def attributes(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#attributes

        **QList<quint16> QBluetoothServiceInfo::attributes() const**

        Returns a list of all attribute ids that the **QBluetoothServiceInfo**
        object has.
        """
        ...

    def attribute(self, attributeId: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#attribute

        **QVariant QBluetoothServiceInfo::attribute(quint16 attributeId )
        const**

        Returns the value of the attribute **attributeId**.

        **See also** **setAttribute** ().
        """
        ...

    def device(self) -> QBluetoothDeviceInfo:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#device

        **QBluetoothDeviceInfo QBluetoothServiceInfo::device() const**

        Returns the address of the Bluetooth device that provides this service.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, info: QBluetoothDeviceInfo) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#setDevice

        **void QBluetoothServiceInfo::setDevice(const QBluetoothDeviceInfo &
        device )**

        Sets the Bluetooth device that provides this service to **device**.

        **See also** **device** ().
        """
        ...

    def isComplete(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#isComplete

        **bool QBluetoothServiceInfo::isComplete() const**

        Returns true if the **QBluetoothServiceInfo**  object is considered
        complete, otherwise returns false.

        A complete **QBluetoothServiceInfo**  object contains a
        **ProtocolDescriptorList**  attribute.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothserviceinfo.html#isValid

        **bool QBluetoothServiceInfo::isValid() const**

        Returns true if the **QBluetoothServiceInfo**  object is valid,
        otherwise returns false.

        An invalid **QBluetoothServiceInfo**  object will have no attributes.
        """
        ...
